{% extends "base.html" %}
{% load i18n %}
{% load static %}

{% block title %}{% trans 'Password change successful' %}{% endblock %}
{% block robots %}noindex,nofollow{% endblock %}


{% block content %}
<h2>{% trans 'Password change' %}</h2>
    {% if user.username %}
    <div style="padding:2em 3em;color: #4F8A10; background-color:;border: 1px solid; background:url('{% static "images/icons/icon_confirmation.gif') #DFF2BF no-repeat; background-position: 10px 50%" %}">
	<h2 style="display:inline; padding-left:10px">{% trans "Password change was successfull."%}</h2>
</div>
<p>{% blocktrans %}Here's a link to the {% endblocktrans %}<a href='{% url "current_user_profile" %}'>profile page</a>.</p>
    {% else %}
       <p>{% trans "Login first in order to change password" %}</p>
    {% endif %}
{% endblock %}

