{% extends "registration/base.html" %}
{% load i18n %}

{% block title %}Account activation{% endblock %}

{% block extrajs %}
<script type='text/javascript'>
$(document).ready(function(){
    $('a.loginform').attr('href', '{% url "auth_login" %}')
}
);
</script>
{% endblock %}

{% block content %}
  {% load humanize %}
  <h1>{% trans "Account activated" %}.</h1>
  <p>Thanks for signing up! Now you can <a href="{% url "auth_login" %}">log in</a>.</p>
{% endblock %}
