{% extends "base.html" %}
{% load i18n %}
{% load static %}
{% load form_as_table %}


{% block title %}{% trans "Password reset" %}{% endblock %}
{% block robots %}noindex,nofollow{% endblock %}

{% block extrajs %}
<script type="text/javascript" src="{% static "userprofile/js/jquery.validation.js" %}"></script>
<script type="text/javascript">
	$(function() {
		$("#id_email").focus();
		$("input[type='text']").addClass("text");
	});
</script>
{% endblock %}

{% block content %}
  <h2>{% trans "Password reset form" %}</h2>
  <p>{% trans "Forgotten your password? Enter your e-mail address, and we'll reset your password and e-mail the new one to you." %}</p>
    
  <div class="generic_form">
    <form action="{% url "password_reset" %}" method="post" accept-charset="utf-8">
    {% csrf_token %} 
    <table class="table_container"><tbody>
      {% form_as_table_rows form %}
    </tbody></table>
    <p class="submit"><input type="submit" class="i16 submit" value="{% trans "Reset my password" %}" /></p>
    </form>
  </div>
{% endblock %}
