{% extends "base.html" %}
{% load i18n %}
{% load form_as_table %}

{% block title %}{% trans 'Password change for' %} {{ user }}{% endblock %}
{% block robots %}noindex,nofollow{% endblock %}

{% block extrajs %}
<script type="text/javascript">
	$(function() {
		$("#id_old_password").focus();
		$("input[type='password']").addClass("text");
	});
</script>
{% endblock %}

{% block content %}
<h2>{% trans 'Password change' %}</h2>
<p>{% trans "You can change your password from here. Please enter your new password twice so we can verify you typed it in correctly." %}</p>
<div class="generic_form">
  <form class="personal" action="{% url "auth_password_change" %}" method="post" enctype="multipart/form-data">
    {% csrf_token %} 
    <table class="table_container"><tbody>
      {% form_as_table_rows form %}
  </tbody></table>
  <p class="submit"><input type="submit" class="i16 submit" value="{% trans "Change" %}" /></p>
</form>

	</form>
{% endblock %}
