{% extends "base.html" %}
{% load i18n %}

{% block title %}{% trans "Logged out" %}{% endblock %}

{% block extrajs %}
<script type='text/javascript'>
$(document).ready(function(){
    $('a.loginform').attr('href', '{% url "auth_login" %}')
}
);
</script>
{% endblock %}

{% block content %}
<div class="notice">
    <h3>{% trans "Logged out" %}</h3>
    <p class="large">{% trans "You've been logged out." %} (<a href="{% url "auth_login" %}">{% trans 'Log in again' %}</a>)</p>
</div>
{% endblock %}
