{% extends "base.html" %}
{% load i18n %}

{% block title %}{% trans "Sign up" %}{% endblock %}

{% block content %}

  <h3>{% trans "Create an account" %}</h3>
     
  {% if form.errors %}
  <p class="error">{% trans "Please correct the errors below: " %}{{ form.non_field_errors }}</p>
  {% endif %}
    
  <form method="post" action="" class="wide">
    {% csrf_token %} 
    <table>  
    <tbody>
      {{ form.as_table }}
    </tbody>
    </table>
    <p class="submit"><input type="submit" value="{% trans "Register" %} &rarr;"></p>
  </form>
     
    
  <p>{% trans "Please fill out the form (all fields are required), and your account will be created." %}<br>
  {% trans "You'll then be sent an email with instructions on how to finish your registration." %}</p>
    
  <p>{% trans "If you already have an account, you can" %} <a href="{% url "auth_login" %}">{% trans "login here" %}</a>.</p>
    
{% endblock %}
    
{% block login %}{% endblock %}
