{% extends "registration/base.html" %}

{% block title %}Registration complete{% endblock %}

{% block content %}
<h1>Check your email</h1>
<p>An activation link has been sent to the email address you supplied, along with instructions for activating your account.</p>
{% endblock %}