{% load i18n %}
{% load static %}
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
   "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">

<html xmlns="http://www.w3.org/1999/xhtml" lang="en">
<head>
  <meta http-equiv="Content-Type" content="text/html; charset=utf-8"/>
  <meta http-equiv="X-UA-Compatible" content="IE=7" />
  <script type="text/javascript">var map_mode=1;</script>

  <link media="screen" href="{% static "css/base.css" %}" type="text/css" rel="stylesheet" />
  <link media="screen" href="{% static "css/olmap.css" %}" type="text/css" rel="stylesheet" />
  <script type="text/javascript" src="//cdnjs.cloudflare.com/ajax/libs/jquery/1.10.2/jquery.min.js"></script>
  <script type="text/javascript" src="//cdnjs.cloudflare.com/ajax/libs/jqueryui/1.10.3/jquery-ui.min.js"></script>
  <script type="text/javascript" src="//cdnjs.cloudflare.com/ajax/libs/jquery.tablesorter/2.10.8/jquery.tablesorter.min.js"></script>
  <script type="text/javascript" src="{% static "js/jquery.placeholder-1.0.1.js" %}"></script>
  <script type="text/javascript">
  </script>
  <script type="text/javascript">
    var STATIC_URL = "{% static "" %}";
    var ENHYDRIS_ROOT_URL = '{% url "station_list" %}';
    var BOUNDING_BOX_URL = '{% url "enhydris.hcore.views.bounding_box" %}';
    var map_mode=1;
  </script>

        <script src="//cdnjs.cloudflare.com/ajax/libs/openlayers/2.12/OpenLayers.min.js">
        </script>

        <script type="text/javascript"
                src="//openstreetmap.org/openlayers/OpenStreetMap.js">
        </script>
        <script type="text/javascript" src="{% static "js/olmap-settings.js" %}"></script>
        <script type="text/javascript" src="{% static "js/olmap.js" %}"></script>
    <style type="text/css">
    #map {
        width: 100%;
        height: 100%;
        border: 1px solid #eee;
        z-index: 1;
    }
    </style>
</head>
<body onload="init()" style="overflow:hidden;">
    <div id="map" style="float: left;">
    <div id="processing_indicator" style="position: absolute; margin-top:49%; margin-left: 49%; z-index: 5000;"></div></div>
</body>
</html>
