# Enhydris settings for {{ project_name }} project.
#
# Generated by 'enhydris-admin newinstance' using Enhydris {{ enhydris_version }}
# and Django {{ django_version }}.
#
# For more information on this file, see
# http://enhydris.readthedocs.org/en/{{ enhydris_docs_version }}/general/install.html#settings-reference

from enhydris.settings.base import *

# SECURITY WARNING: don't run with debug turned on in production!
DEBUG = True
TEMPLATE_DEBUG = DEBUG

# SECURITY_WARNING: Keep the secret key used in production secret!
SECRET_KEY = '{{ secret_key }}'

# List the domains through which this instance will be accessible. Enhydris
# will refuse to serve other domains.
ALLOWED_HOSTS = ['example.com']

# Administrators who will be notified whenever attention is needed.
ADMINS = (
    # ('Your Name', 'your_email@domain.com'),
)
MANAGERS = ADMINS

# Whenever the system emails users, this is the address from which the emails
# will appear to have been sent.
DEFAULT_FROM_EMAIL = 'noreply@example.com'

# Whenever the system emails administrators, this is the address from which the
# emails will appear to have been sent.
SERVER_EMAIL = DEFAULT_FROM_EMAIL

DATABASES = {
    'default': {
        'ENGINE': 'django.contrib.gis.db.backends.postgis',
        'NAME': 'enhydris_db',
        'USER': 'enhydris_user',
        'PASSWORD': 'topsecret',
        'HOST': 'localhost',
        'PORT': '5432',
    }
}

# Default system timezone, such as 'Europe/Athens'.
TIME_ZONE = 'UTC'

# You should probably leave this as it is. See the installation instructions if
# in doubt.
SITE_ID = 1

# Where static files will be stored. By "static" files we mean css, javascript,
# and images of the skin. These files will be copied there at installation
# time when executing "python manage.py collectstatic".
STATIC_ROOT = '/var/cache/enhydris/static/'


# Where media files will be stored. "media" files are static files uploaded
# by users, e.g. images and videos of stations. The web server must be
# configured to map the URL /enhydris-media/ to that directory. See the
# installation instructions for more information.
MEDIA_ROOT = '/var/lib/enhydris/media/'

# The web server must be configured to map the URLs below to the directories
# specified by STATIC_ROOT and MEDIA_ROOT above. Enhydris will use the settings
# below to create appropriate links.
STATIC_URL = '/enhydris-static/'
MEDIA_URL = '/enhydris-media/'

# Mail server settings; used whenever the system needs to email users or
# admins.
EMAIL_USE_TLS = True
EMAIL_PORT = 587
EMAIL_HOST = 'smtp.example.com'
EMAIL_HOST_USER = 'emailuser'
EMAIL_HOST_PASSWORD = 'topsecret'

# The above are only the settings that are absolutely essential. Check the
# installation instructions for more settings that you can set.
