{% extends "base.html" %}
{% load i18n %}

{% block title %}{% trans 'Password reset successful' %}{% endblock %}
{% block robots %}noindex,nofollow{% endblock %}

{% block content %}
	<div class="success">
		<h3>{% trans "Password reset successful" %}</h3>
		<p>{% trans "We've e-mailed you the instructions to obtain a new password. You should be receiving it shortly." %}</p>
	</div>
{% endblock %}

