/* General */
html, body { 
	margin: 0;
	padding: 0;
	min-height:100%;
	max-height:100%;
	height:100%;

}
body {
  font-family: sans-serif;
  font-size: 0.85em;
  color: #333;
  padding: 0;
  margin: 0;
}

input,select{
    -moz-border-radius-bottomleft:5px;
    -moz-border-radius-bottomright:5px;
    -moz-border-radius-topleft:5px;
    -moz-border-radius-topright:5px;
    -webkit-border-radius: 5px;
    font-size:0.85em;
}


/* Header */

div#wrapper {
	min-height: 100%;
	height: auto !important;
	height: 100%;
	margin: 0 auto;
	min-width: 1024px;
    padding: 0;
}

div#header {
    background-color: black;
    height: 25px;
    padding: 5px 20px;
    min-width: 500px;
}

div#header lang_switcher {
/*  margin-left: 1em; */
}

div#header div#navmenu {
/*  margin: 40px 0.5em 0 10em; */
  font-size: 150%;
  color: #ccc;
}

#menu { float: left; list-style: none outside none; margin: 0; padding: 0; }
#menu a { color: white; text-decoration: none; } 
#menu > li { float: left; margin-right: 15px; }
#menu > li a:hover {color: #B0D730; text-decoration: none; } 
#menu2 { float: right; list-style: none outside none; margin:0; padding: 0; }
#menu2 a { color: white; text-decoration: none; } 
#menu2 > li { float: left; margin-left: 15px; }
#menu2 > li a:hover {color:#B0D730; text-decoration: none; } 

.searchContainer input[type="text"] {border:none; } 
.searchContainer img { vertical-align:middle;}

/* Search tips */

.ui-dialog {
    z-index: 2000 !important;
}
#searchtips h3 {
    font-size: 100%;
    margin-bottom: 0;
}
#searchtips p {
    font-size: 90%;
    line-height: 1.2em;
    margin-top: 0.75em;
    margin-bottom: 0.75em;
}
#searchtips p.code {
    font-family: monospace;
    font-size: 110%;
    line-height: 1.2em;
    border: solid #ddd 1px;
    background-color: #eee;
}
#searchtips hr {
    background-color: #bbd;
    width: 80%;
    border: none;
}

/* Content */

div#body {
  clear: both;
  background-color: white;
  -moz-border-radius: 10px;
  -webkit-border-radius: 10px;
  margin: 1em 0;
  min-height: 40em;
  padding: 0.5em 20px 2em 20px;
  overflow:auto;
}

div#body h2 {
  font-weight: normal;
  font-size: 1.8em;
  margin-left: 0;
  margin-top: 1.5em;
  color: #666;
}

div#body h3 {
  margin-top: 1.2em;
  color: #b65d0e;
  font-weight: normal;
}

div#body h4 {
  text-transform: uppercase;
  color: #666;
  font-weight: bold;
}

/* Other elements */

a, a:visited {
  color: #4c0d8c;
  text-decoration: none;
  border-bottom: none;
}

a:hover {
  text-decoration: none;
  border-bottom: 1px solid #aaa;
}

code { font-size: 1.2em; }

span[title] {
	border: 0;
	border-bottom: 1px dotted #b88;
 	cursor: help;
}

ul li, ol li {
/*  margin-top: 0.5em;*/
  margin-bottom: 0.5em;
}

.messages {
  text-align: center;
  padding-top: 10px;
  margin: 2px;
}

.message {
  -moz-border-radius: 5px;
  -webkit-border-radius: 5px;
  border-width: 1px;
  border-style: solid;
  padding: 0.5em;
  background-color: #ffffe0;
  border-color: #e6db55;
  margin: 0px;
  font-size: 0.9em;
}

input {
  font-family: sans-serif;
  -moz-border-radius: 2px;
  -webkit-border-radius: 2px;
}

textarea {
  font-family: sans-serif;
  border: 1px solid #aaa;
  -moz-border-radius: 2px;
  -webkit-border-radius: 2px;
}

.floatright {
  float: right;
  margin-left: 1em;
}

ul.errorlist li {
  color: #c27878;
}

ul.notifications {
    margin:0;
    padding:0;
    border: 1px solid red;
    margin: 10px 0px;
    padding:25px 10px 15px 50px;
    background: url('../images/icons/delete.png')  no-repeat;
    background-position: 10px center;
    background-color: #FFBABA;
}


li.error {
    color: #D8000C;

    list-style-type: none;
}

.fielderrors {
  color: #c27878;
}
a.tag:link, a.tag:hover, a.tag:visited {
  color:#555;
}

a.tag {
  background-color:#FFFCE7;
  -moz-border-radius: 2px;
  -webkit-border-radius: 2px;
  border-color: #F9F5EA #EEE2BF #EEE2BF #F9F5EA;
  border-style: solid;
  border-width: 1px;
  line-height: 1.5em;
  padding: 0.15em 0.2em;
  font-size: 95%;
}

a.collapse_toggler{ 
  cursor: pointer;
} 

.expArrow{
    padding-left: 20px;
    font-weight: bold;
    color: #000055;
    background: url(../images/arrow-down.png) no-repeat 0px 4px;
    cursor: pointer;
}

.collArrow{
    padding-left: 20px;
    font-weight: bold;
    color: #000055;
    background: url(../images/arrow-up.png) no-repeat 0px 4px;
    cursor: pointer;
}

.sup_link { 
  font-size:10pt;
}

table.formset {
  border-width: 1px 1px 1px 1px;
  border-spacing: 2px;
  border-style: outset outset outset outset;
  border-color: gray gray gray gray;
  border-collapse: collapse;
  background-color: rgb(250, 240, 230);
}

table.formset td {
  border-width: 1px 1px 1px 1px;
  padding: 1px 1px 1px 1px;
  border-style: solid solid solid solid;
  border-color: gray gray gray gray;
  background-color: white;
  -moz-border-radius: 0px 0px 0px 0px;
  -webkit-border-radius: 0px 0px 0px 0px;
}


/* ICONS */
.i16 {
    background-repeat: no-repeat;
	padding-left: 24px;
	-moz-border-radius-bottomleft:3px;
	-moz-border-radius-bottomright:3px;
	-moz-border-radius-topleft:3px;
	-moz-border-radius-topright:3px;
	background-position:5px 50%;
	padding-bottom:6px;
	padding-right:6px;
	padding-top:6px;
	font-size: 1em;
}

.i16.long {
	padding: 1px 6px 2px 24px;
}

.i16.submit { background-image:url('../images/icons/tick.png'); }
.i16.show_list { background-image: url('../images/icons/table_refresh.png'); }
.i16.magnifier { background-image: url('../images/icons/magnifier.png'); }
.i16.help { background-image: url('../images/icons/help.png'); }


/* Tables Related Stuff */
.data_table{
    font-family: Verdana,Arial,sans-serif;
    font-size: 0.8em;
    border: 2px solid #EEEEEE;
}
table.table thead th a {
    color: black;
}

/* Buttons with Jquery :) */
.fg-button { 
   outline: 0; 
   padding: .4em .4em; 
   text-decoration:none !important; 
   cursor:pointer; 
   position: relative; 
   text-align: center; 
   zoom: 1; 
   height:100%;
   overflow: hidden;
   width:180px;
}

.fg-button-icon-left{
    float: left;
}
.fg-button-icon-right{
    float: right;
}

#frontpage_text {
    float:left;
	width:650px;
}

#frontpage {
    float:right;
	width:400px;
	font-size:0.85em;
	margin-top: 8em;
}


#frontpage div{
    color:#3E3E3E;
    background-color:#F4F4EE;
    border: 1px solid #CCCCCC;
    padding: 10px 15px 5px 15px;
    position: relative;
    -webkit-border-radius: 5px;
    -moz-border-radius:5px;
}

#frontpage div h3 {
    background-color: #EEE;
    padding:2px 14px;
}
#frontpage div p {
	margin:0;
	padding:0;
	line-height:20px;
}

#frontpage div span {
    color:#2B88C2;
}

#frontpage div .header {
    color: black;
}

#login_form {
	-moz-background-clip:border;
	-moz-background-inline-policy:continuous;
	-moz-background-origin:padding;
	-moz-border-radius-bottomleft:7px;
	-moz-border-radius-topright:7px;
	background:#F4F4EE none repeat scroll 0 0;
	border:1px solid #bbb;
	margin:2em auto;
	text-align:center;
	width:300px;
	padding: 1em;
}

div#menu_bar {
	-moz-background-clip:border;
	-moz-background-inline-policy:continuous;
	-moz-background-origin:padding;
	background:#F6F6EA none repeat scroll 0 0;
	color:#A4A4A4;
	font-size:10px;
	height:23px;
	line-height:23px;
	margin-bottom:2em;
	padding:0 10px;
}

.menu_options {
	padding: 0.2em 0.5em;
}

.mgmt_button { 
    border: 0;
}


#global-search-form input {
background-image:url(../images/icons/magnifier.png);
background-position: right center;
background-repeat:no-repeat;
background-color: #fff;
font-size:14px;
line-height: 20px;
margin-top: 0px;
width: 150px;
padding:3px 20px 3px 5px;
}

#global-search-form input.placeholder { color:#bbb; font-style:italic;}
#global-search-form button  { display: none !important; }

