{% extends "registration/base.html" %}
{% load i18n %}

{% block title %}Account activation failed{% endblock %}

{% block extrajs %}
<script type='text/javascript'>
$(document).ready(function(){
    $('a.loginform').attr('href', '{% url "auth_login" %}')
}
);
</script>
{% endblock %}

{% block content %}
  {% load humanize %}
  <h1>{% trans "Account activation failed" %}.</h1>
  <p>Sorry, it didn't work. Either your activation link was incorrect, or
  the activation key for your account has expired; activation keys are
  only valid for {{ expiration_days|apnumber }} days after
  registration.</p>
{% endblock %}
